==> senior_design_system-0.21.4.tar.gz: example/lib/pages/text_field.example.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class TextFieldExample extends StatelessWidget {
  TextFieldExample({Key? key}) : super(key: key);

  bool hidePassword = true;

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Text Field',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(SeniorSpacing.normal),
          child: Column(
            children: [
              Panel(
                title: 'Normal',
                child: SeniorTextField(
                  controller: TextEditingController(),
                  hintText: 'Nome',
                  maxLength: 43,
                  counterCaracterLabel: 'words',
                ),
              ),
              Panel(
                title: 'Text area',
                child: SeniorTextField(
                  controller: TextEditingController(),
                  label: 'Descrição',
                  maxLines: 3,
                  leftIcon: FontAwesomeIcons.rocket,
                ),
              ),
              Panel(
                title: 'Limite caracteres',
                child: SeniorTextField(
                  controller: TextEditingController(),
                  label: 'Nome',
                  maxLength: 10,
                ),
              ),
              Panel(
                title: 'Com validator',
                child: SeniorTextField(
                  controller: TextEditingController(),
                  maxLength: 30,
                  label: 'Sobrenome',
                  helper: 'Helper do campo',
                  validator: (value) {
                    return value == null || value.isEmpty ? 'Campo obrigatório' : null;
                  },
                ),
              ),
              Panel(
                title: 'Campo de senha',
                child: SeniorTextField.password(
                  controller: TextEditingController(),
                  label: 'Senha',
                  validator: (value) {
                    return value == null || value.isEmpty ? 'Campo obrigatório' : null;
                  },
                  textInputAction: TextInputAction.next,
                ),
              ),
              Panel(
                title: 'Ícone à esquerda',
                child: SeniorTextField(
                  controller: TextEditingController(),
                  label: 'Início',
                  leftIcon: FontAwesomeIcons.calendar,
                ),
              ),
              Panel(
                title: 'Ícone à direita',
                child: SeniorTextField(
                  controller: TextEditingController(),
                  label: 'Fim',
                  rightIcon: FontAwesomeIcons.search,
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> senior_design_system-0.26.2.tar.gz: example/lib/pages/text_field.example.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class TextFieldExample extends StatelessWidget {
  TextFieldExample({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Text Field',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(SeniorSpacing.normal),
          child: Column(
            children: [
              Panel(
                title: 'Normal',
                child: SeniorTextField(
                  controller: TextEditingController(),
                  hintText: 'Nome',
                  maxLength: 43,
                  counterCaracterLabel: 'words',
                ),
              ),
              Panel(
                title: 'Text area',
                child: SeniorTextField(
                  controller: TextEditingController(),
                  label: 'Descrição',
                  maxLines: 3,
                  leftIcon: FontAwesomeIcons.rocket,
                ),
              ),
              Panel(
                title: 'Limite caracteres',
                child: SeniorTextField(
                  controller: TextEditingController(),
                  label: 'Nome',
                  maxLength: 10,
                ),
              ),
              Panel(
                title: 'Com validator',
                child: SeniorTextField(
                  controller: TextEditingController(),
                  maxLength: 30,
                  label: 'Sobrenome',
                  helper: 'Helper do campo',
                  validator: (value) {
                    return value == null || value.isEmpty
                        ? 'Campo obrigatório'
                        : null;
                  },
                ),
              ),
              Panel(
                title: 'Campo de senha',
                child: SeniorTextField.password(
                  controller: TextEditingController(),
                  label: 'Senha',
                  validator: (value) {
                    return value == null || value.isEmpty
                        ? 'Campo obrigatório'
                        : null;
                  },
                  textInputAction: TextInputAction.next,
                ),
              ),
              Panel(
                title: 'Ícone à esquerda',
                child: SeniorTextField(
                  controller: TextEditingController(),
                  label: 'Início',
                  leftIcon: FontAwesomeIcons.calendar,
                ),
              ),
              Panel(
                title: 'Ícone à direita',
                child: SeniorTextField(
                  controller: TextEditingController(),
                  label: 'Fim',
                  rightIcon: FontAwesomeIcons.magnifyingGlass,
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
